summaryrefslogtreecommitdiffstats
path: root/krec/krecexport_template.h
diff options
context:
space:
mode:
Diffstat (limited to 'krec/krecexport_template.h')
-rw-r--r--krec/krecexport_template.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/krec/krecexport_template.h b/krec/krecexport_template.h
index 8a1c4a03..aac9dac2 100644
--- a/krec/krecexport_template.h
+++ b/krec/krecexport_template.h
@@ -14,11 +14,11 @@
#ifndef KREC_EXPORT_TEMPLATE_H
#define KREC_EXPORT_TEMPLATE_H
-#include <qobject.h>
+#include <tqobject.h>
-#include <qstring.h>
-#include <qstringlist.h>
-#include <qcstring.h>
+#include <tqstring.h>
+#include <tqstringlist.h>
+#include <tqcstring.h>
#include <arts/common.h>
/**
@@ -29,14 +29,14 @@
*
* @author Arnold Krille <arnold@arnoldarts.de>
*/
-class KRecExportItem : public QObject {
+class KRecExportItem : public TQObject {
Q_OBJECT
private:
/// Controls wether an export is running, or not...
bool _running;
int _samplingRate, _bits, _channels;
protected:
- KRecExportItem( QObject*, const char* =0, const QStringList& =0 );
+ KRecExportItem( TQObject*, const char* =0, const TQStringList& =0 );
/**
* This registers this class at the KRecGlobal.
@@ -60,22 +60,22 @@ public:
virtual KRecExportItem* newItem()=0;
/// Returns a list with the extensions.
- virtual QStringList extensions()=0;
+ virtual TQStringList extensions()=0;
/// Returns the export format.
- virtual QString exportFormat()=0;
+ virtual TQString exportFormat()=0;
bool running() const { return _running; }
public slots:
/**
* Initializes the sound-settings.
* Has to be called before the initialize( const QString & ) function.
*/
void initialize( int samplingRate, int bits, int channels );
/// Initializes the export.
- virtual bool initialize( const QString &filename )=0;
+ virtual bool initialize( const TQString &filename )=0;
/**
* Start the real export (including the emission of @see getData() while running=true).
- * Best way to do this is to use @see QTimer::singleShot() since then the events are
+ * Best way to do this is to use @see TQTimer::singleShot() since then the events are
* put at the end of the EventLoop not blocking the gui and everything else.
*/
bool start();
@@ -85,10 +85,10 @@ public slots:
void stop();
/// Finish the export.
virtual bool finalize()=0;
- //virtual void data( QByteArray& );
+ //virtual void data( TQByteArray& );
signals:
/// Is emitted when this Item wants data to export.
- void getData( QByteArray& );
+ void getData( TQByteArray& );
void running( bool );
};
@@ -60,22 +60,22 @@ public:
/**
* Initializes the sound-settings.
- * Has to be called before the initialize( const QString & ) function.
+ * Has to be called before the initialize( const TQString & ) function.
*/
void initialize( int samplingRate, int bits, int channels );